==> fasc-openapi-java-sdk-5.7.2.0815-sources.jar: com/fasc/open/api/v5_1/client/ApproveClient.java <==
package com.fasc.open.api.v5_1.client;

import com.fasc.open.api.bean.base.BaseRes;
import com.fasc.open.api.constants.OpenApiUrlConstants;
import com.fasc.open.api.exception.ApiException;
import com.fasc.open.api.v5_1.req.approval.*;
import com.fasc.open.api.v5_1.res.approval.*;

import java.util.List;

/**
 * @author Fadada
 * 2023/06/14 16:48:09
 */
public class ApproveClient {

    private OpenApiClient openApiClient;

    public ApproveClient(OpenApiClient openApiClient) {
        this.openApiClient = openApiClient;
    }


    public BaseRes<GetApprovalUrlRes> approvalGetUrl(GetApprovalUrlReq req) throws ApiException {
        return openApiClient.invokeApi(req, OpenApiUrlConstants.APPROVAL_GET_URL, GetApprovalUrlRes.class);
    }

    /***/
    public BaseRes<List<GetApprovalFlowListRes>> approvalFlowGetList(GetApprovalFlowListReq req) throws ApiException {
        return openApiClient.invokeApiList(req, OpenApiUrlConstants.APPROVAL_FLOW_GET_LIST, GetApprovalFlowListRes.class);
    }

    /***/
    public BaseRes<GetApprovalFlowDetailRes> approvalFlowGetDetail(GetApprovalFlowDetailReq req) throws ApiException {
        return openApiClient.invokeApi(req, OpenApiUrlConstants.APPROVAL_FLOW_GET_DETAIL, GetApprovalFlowDetailRes.class);
    }

    public BaseRes<GetApprovalInfoListRes> approvalGetList(GetApprovalInfoListReq req) throws ApiException {
        return openApiClient.invokeApi(req, OpenApiUrlConstants.APPROVAL_GET_LIST, GetApprovalInfoListRes.class);
    }

    public BaseRes<GetApprovalDetailRes> approvalGetDetail(GetApprovalDetailReq req) throws ApiException {
        return openApiClient.invokeApi(req, OpenApiUrlConstants.APPROVAL_GET_DETAIL, GetApprovalDetailRes.class);
    }


}

==> fasc-openapi-java-sdk-5.7.8.1125-sources.jar: com/fasc/open/api/v5_1/client/ApproveClient.java <==
package com.fasc.open.api.v5_1.client;

import com.fasc.open.api.bean.base.BaseRes;
import com.fasc.open.api.constants.OpenApiUrlConstants;
import com.fasc.open.api.exception.ApiException;
import com.fasc.open.api.v5_1.req.approval.*;
import com.fasc.open.api.v5_1.res.approval.*;

import java.util.List;

/**
 * @author Fadada
 * 2023/06/14 16:48:09
 */
public class ApproveClient {

    private OpenApiClient openApiClient;

    public ApproveClient(OpenApiClient openApiClient) {
        this.openApiClient = openApiClient;
    }


    public BaseRes<GetApprovalUrlRes> approvalGetUrl(GetApprovalUrlReq req) throws ApiException {
        return openApiClient.invokeApi(req, OpenApiUrlConstants.APPROVAL_GET_URL, GetApprovalUrlRes.class);
    }

    /***/
    public BaseRes<List<GetApprovalFlowListRes>> approvalFlowGetList(GetApprovalFlowListReq req) throws ApiException {
        return openApiClient.invokeApiList(req, OpenApiUrlConstants.APPROVAL_FLOW_GET_LIST, GetApprovalFlowListRes.class);
    }

    /***/
    public BaseRes<GetApprovalFlowDetailRes> approvalFlowGetDetail(GetApprovalFlowDetailReq req) throws ApiException {
        return openApiClient.invokeApi(req, OpenApiUrlConstants.APPROVAL_FLOW_GET_DETAIL, GetApprovalFlowDetailRes.class);
    }

    public BaseRes<Void> approvalOperate(ApprovalOperateFromApiReq req) throws ApiException {
        return openApiClient.invokeApi(req, OpenApiUrlConstants.APPROVAL_OPERATE, Void.class);
    }

    public BaseRes<GetApprovalInfoListRes> approvalGetList(GetApprovalInfoListReq req) throws ApiException {
        return openApiClient.invokeApi(req, OpenApiUrlConstants.APPROVAL_GET_LIST, GetApprovalInfoListRes.class);
    }

    public BaseRes<GetApprovalDetailRes> approvalGetDetail(GetApprovalDetailReq req) throws ApiException {
        return openApiClient.invokeApi(req, OpenApiUrlConstants.APPROVAL_GET_DETAIL, GetApprovalDetailRes.class);
    }


}
